@@ -98,12 +98,8 @@ public class OnlinePublicationServlet extends HttpServlet {
             // create a new HttpSession if it's missing
             req.getSession(true);
             super.service(new CountingHttpServletRequest(req), resp);
-        } catch (final RateLimitedException e) {
-            resp.setContentType("text/plain; charset=UTF-8");
-            if(e.getRetryAfter() > 0) {
-                resp.setHeader("Retry-After", String.valueOf(e.getRetryAfter()));
-            }
-            resp.sendError(429, "Too Many Requests - Your request is being rate limited.");
+        } catch (RateLimitedException e) {
+            e.send(resp);
         }
     }
 
